function f=fun6b(alfa,p)
% APRENDIZAJE AUTOMÁTICO (G. Pajares y J.M. de la Cruz, Eds.)
% Editorial: RA-MA
% Capítulo 1: Introducción
% Autores: Jesús Manuel de la Cruz García, Gonzalo Pajares Martinsanz
%
% Ejemplo de regresión
% alfa: vector de parámetros del modelo o función
% p:    vector de observaciones
% f:    suma de los cuadrados de los residuos o diferencia 
%       entre valores observados y valores que predice el modelo 
f=p(:,1)-alfa(1)*exp(-alfa(2).*p(:,2));
f=f'*f;